@@ -9,7 +9,7 @@ from io import StringIO
 import prettytable
 import sqlalchemy
 import sqlparse
-
+import sql.connection
 from .column_guesser import ColumnGuesserMixin
 
 try:
@@ -101,21 +101,19 @@ class ResultSet(list, ColumnGuesserMixin):
     Can access rows listwise, or by string value of leftmost column.
     """
 
-    def __init__(self, sqlaproxy, sql, config):
-        self.keys = sqlaproxy.keys()
-        self.sql = sql
+    def __init__(self, sqlaproxy, config):
         self.config = config
-        self.limit = config.autolimit
-        style_name = config.style
-        self.style = prettytable.__dict__[style_name.upper()]
+        self.keys = {}
         if sqlaproxy.returns_rows:
-            if self.limit:
-                list.__init__(self, sqlaproxy.fetchmany(size=self.limit))
+            self.keys = sqlaproxy.keys()
+            if config.autolimit:
+                list.__init__(self, sqlaproxy.fetchmany(size=config.autolimit))
             else:
                 list.__init__(self, sqlaproxy.fetchall())
             self.field_names = unduplicate_field_names(self.keys)
-            self.pretty = PrettyTable(self.field_names, style=self.style)
-            # self.pretty.set_style(self.style)
+            self.pretty = PrettyTable(
+                self.field_names, style=prettytable.__dict__[config.style.upper()]
+            )
         else:
             list.__init__(self, [])
             self.pretty = None
@@ -166,12 +164,23 @@ class ResultSet(list, ColumnGuesserMixin):
         for row in self:
             yield dict(zip(self.keys, row))
 
-    @telemetry.log_call("data-frame")
-    def DataFrame(self):
+    @telemetry.log_call("data-frame", payload=True)
+    def DataFrame(self, payload):
         "Returns a Pandas DataFrame instance built from the result set."
         import pandas as pd
 
         frame = pd.DataFrame(self, columns=(self and self.keys) or [])
+        payload[
+            "connection_info"
+        ] = sql.connection.Connection._get_curr_connection_info()
+        return frame
+
+    @telemetry.log_call("polars-data-frame")
+    def PolarsDataFrame(self):
+        "Returns a Polars DataFrame instance built from the result set."
+        import polars as pl
+
+        frame = pl.DataFrame((tuple(row) for row in self), schema=self.keys)
         return frame
 
     @telemetry.log_call("pie")
@@ -394,9 +403,11 @@ def run(conn, sql, config, user_namespace):
             _commit(conn=conn, config=config)
             if result and config.feedback:
                 print(interpret_rowcount(result.rowcount))
-        resultset = ResultSet(result, statement, config)
+        resultset = ResultSet(result, config)
         if config.autopandas:
             return resultset.DataFrame()
+        elif config.autopolars:
+            return resultset.PolarsDataFrame()
         else:
             return resultset
         # returning only last result, intentionally
